Metric Generators
=================

.. toctree::

    stonesoup.metricgenerator.basicmetrics
    stonesoup.metricgenerator.tracktotruthmetrics
    stonesoup.metricgenerator.ospametric

.. automodule:: stonesoup.metricgenerator
    :no-members:

.. automodule:: stonesoup.metricgenerator.base
    :show-inheritance:
